@@ -21,7 +21,7 @@ from telemetry_peak_analyzer import models
 class AbstractAnalyzer(abc.ABC):
     """Abstract analyzer."""
 
-    DEFAULT_METRIC_TABLE_AGE = datetime.timedelta(days=10)
+    DEFAULT_GLOBAL_TABLE_AGE = datetime.timedelta(days=7)
 
     @staticmethod
     def _get_window_count(start_ts: int, end_ts: int) -> int:
@@ -435,7 +435,7 @@ class TwoIndexTwoDimensionAnalyzer(AbstractAnalyzer, ABC):
         :return: the global tables
         """
         end_date = datetime.datetime.utcnow()
-        start_date = end_date - self.DEFAULT_METRIC_TABLE_AGE
+        start_date = end_date - self.DEFAULT_GLOBAL_TABLE_AGE
         ret = self._backend.stats(
             start_date=start_date,
             end_date=end_date,
@@ -596,3 +596,55 @@ class FileTypePeakAnalyzer(TwoIndexTwoDimensionAnalyzer):
             start_ts=start_ts,
             end_ts=end_ts,
         )
+
+
+class NetworkTypePeakAnalyzer(TwoIndexTwoDimensionAnalyzer):
+    """Analyzer using index and dimension to track network peaks."""
+
+    CROSS_DIMENSIONS = [
+        "source.user_id",
+    ]
+
+    DIMENSIONS_METADATA = {
+        "event.impact": {
+           "values": ["70", "30"],
+        }
+    }
+
+    _INDEX = [
+        "utc_timestamp",
+        "event.id",
+    ]
+
+    _DIMENSIONS = [
+        "event.impact",
+        "threat.name.keyword",
+    ]
+
+    def __init__(
+        self,
+        conf: configparser.ConfigParser,
+        backend: backends.BackendType,
+        start_ts: datetime.datetime,
+        end_ts: datetime.datetime,
+    ) -> None:
+        """
+        Constructor.
+
+        :param configparser.ConfigParser conf: the conf object
+        :param backendType backend: the backend
+        :param datetime.datetime start_ts: the beginning of the time interval
+        :param datetime.datetime end_ts: the end of the time interval
+        """
+        if not isinstance(backend, backends.TwoIndexTwoDimensionBackend):
+            raise ValueError("Backend is not compatible with the chosen analyzer")
+        # Relax the default age of a global table when not present
+        self.DEFAULT_METRIC_TABLE_AGE = datetime.timedelta(days=3)
+        super(NetworkTypePeakAnalyzer, self).__init__(
+            conf=conf,
+            index=self._INDEX,
+            dimensions=self._DIMENSIONS,
+            backend=backend,
+            start_ts=start_ts,
+            end_ts=end_ts,
+        )
